==> coventry-0.8.1.tar.gz: coventry-0.8.1/src/messages.hpp <==
/*
 * Copyright (C) 2021 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MESSAGES_HPP_
#define MESSAGES_HPP_

#include <moderncli/strings.hpp>

#include <ctime>

#include "utils.hpp"
#include "exosip.hpp"

namespace server {
class message {
public:
    message(std::string_view from_name, std::string_view to_uri, std::string_view route_to, std::string_view msg_subject, std::string_view msg_text, std::string_view msg_type, eXosip_t *context);

    message(int dialog, int status, int reason, std::string_view msg_subject, std::string_view msg_text, std::string_view msg_type, eXosip_t *context);

    message() = default;

    inline auto from() const {
        return ctx_ ? data_->from : "";
    }

    inline auto to() const {
        return ctx_ ? data_->to : "";
    }

    inline auto subject() const {
        return ctx_ ? data_->subject : "";
    }

    inline auto route() const {
        return ctx_ ? data_->route.c_str() : "";
    }

    inline auto text() const {
        return ctx_ ? data_->text.c_str() : "";
    }

    inline auto size() const {
        return str_size(text(), 160);
    }

    inline auto context() const {
        return ctx_;
    }

    inline auto type() const {
        return ctx_ ? data_-> type : "text/plain";
    }

    inline auto body() const {
        return std::string_view(text());
    }

    inline auto did() const {
        return did_;
    }

    inline auto status() const {
        return did_ != -1 ? data_->status : EXOSIP_SUBCRSTATE_UNKNOWN;
    }

    inline auto reason() const {
        return did_ != -1 ? data_->reason : DEACTIVATED;
    }

private:
    struct data {
        data(const std::string_view& from_name, const std::string_view& to_uri, const std::string_view& route_uri, const std::string_view& msg_subject, const std::string_view& msg_text, const std::string_view& msg_type) :
        from{from_name}, to{to_uri}, route{route_uri}, subject{msg_subject}, text{msg_text}, type{msg_type} {}

        data(int msg_status, int msg_reason, const std::string_view& msg_subject, const std::string_view& msg_text, const std::string_view& msg_type) :
        subject{msg_subject}, text{msg_text}, type{msg_type}, status{msg_status}, reason{msg_reason} {}

        std::string from, to, route, subject, text, type;
        time_t expires{};
        int status{}, reason{};
    };

    const std::shared_ptr<data> data_;
    eXosip_t *ctx_{nullptr};
    int did_{-1};
};

struct logmsg final {
    logmsg() = delete;

    explicit logmsg(const std::string& text, time_t started = 0) :
    msg(std::move(text)), duration(-1) {
        if(started) {
            time(&duration);
            created = started;
            duration -= created;
        }
        else
            time(&created);
    };

    std::string msg;
    time_t created;
    time_t duration;
};

void exec_messages(const keyfile& config);

// messages component dispatch actions
namespace exec {
void stop_messages();
void reload_messages(const keyfile& config);
void deliver_local(const message& msg);
void notify_local(const message& msg);
void post_log(const logmsg& log);
void post_cdr(const logmsg& cdr);
}} // end namespace
#endif

==> coventry-0.8.6.tar.gz: coventry-0.8.6/src/messages.hpp <==
/*
 * Copyright (C) 2021 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MESSAGES_HPP_
#define MESSAGES_HPP_

#include "server.hpp"        // IWYU pragma: keep
#include "exosip.hpp"

#include <moderncli/strings.hpp>

namespace server {
class message {
public:
    message(std::string_view from_name, std::string_view to_uri, std::string_view route_to, std::string_view msg_subject, std::string_view msg_text, std::string_view msg_type, eXosip_t *context);

    message(int dialog, int status, int reason, std::string_view msg_subject, std::string_view msg_text, std::string_view msg_type, eXosip_t *context);

    message() = default;

    auto from() const {
        return ctx_ ? data_->from : "";
    }

    auto to() const {
        return ctx_ ? data_->to : "";
    }

    auto subject() const {
        return ctx_ ? data_->subject : "";
    }

    auto route() const {
        return ctx_ ? data_->route.c_str() : "";
    }

    auto text() const {
        return ctx_ ? data_->text.c_str() : "";
    }

    auto size() const {
        return str_size(text(), 160);
    }

    auto context() const {
        return ctx_;
    }

    auto type() const {
        return ctx_ ? data_-> type : "text/plain";
    }

    auto body() const {
        return std::string_view(text());
    }

    auto did() const {
        return did_;
    }

    auto status() const {
        return did_ != -1 ? data_->status : EXOSIP_SUBCRSTATE_UNKNOWN;
    }

    auto reason() const {
        return did_ != -1 ? data_->reason : DEACTIVATED;
    }

private:
    struct data {
        data(const std::string_view& from_name, const std::string_view& to_uri, const std::string_view& route_uri, const std::string_view& msg_subject, const std::string_view& msg_text, const std::string_view& msg_type) :
        from{from_name}, to{to_uri}, route{route_uri}, subject{msg_subject}, text{msg_text}, type{msg_type} {}

        data(int msg_status, int msg_reason, const std::string_view& msg_subject, const std::string_view& msg_text, const std::string_view& msg_type) :
        subject{msg_subject}, text{msg_text}, type{msg_type}, status{msg_status}, reason{msg_reason} {}

        std::string from, to, route, subject, text, type;
        time_t expires{};
        int status{}, reason{};
    };

    std::shared_ptr<data> data_;
    eXosip_t *ctx_{nullptr};
    int did_{-1};
};

struct logmsg final {
    logmsg() = delete;

    explicit logmsg(const std::string& text, time_t started = 0) :
    msg(std::move(text)), duration(-1) {
        if(started) {
            time(&duration);
            created = started;
            duration -= created;
        }
        else
            time(&created);
    };

    std::string msg;
    time_t created;
    time_t duration;
};

void exec_messages(const keyfile& config);

// messages component dispatch actions
namespace exec {
void stop_messages();
void reload_messages(const keyfile& config);
void deliver_local(const message& msg);
void notify_local(const message& msg);
void post_log(const logmsg& log);
void post_cdr(const logmsg& cdr);
}} // end namespace
#endif
